@@ -197,6 +197,9 @@ LocalHttpClient::LocalHttpClient(ServerType type)
 #if QT_CONFIG(localserver)
     } else if (type == LOCAL) {
         QLocalSocket *localSocket = new QLocalSocket();
+#ifdef Q_OS_LINUX
+        localSocket->setSocketOptions(QLocalSocket::AbstractNamespaceOption);
+#endif
         localSocket->connectToServer(local);
         QVERIFY2(localSocket->waitForConnected(),
                  "Failed waiting for client local socket to be connected");
@@ -378,8 +381,6 @@ QString LocalHttpClient::fetchResults()
             read += result;
         };
     } else if (transferEncoding.compare("chunked", Qt::CaseInsensitive) == 0) {
-        if (serverType == HTTP1_0)
-            QEXPECT_FAIL("", "QTBUG-138410: The HTTP/1.0 support is incomplete", Abort);
         QVERIFY2(serverType != HTTP1_0, "Chunked encoding not supported for HTTP/1.0");
         read = 0;
         forever {
@@ -643,12 +644,17 @@ void tst_QHttpServerMultithreaded::initTestCase()
                          }
                      });
 
-    httpserver.route("/sequential/<arg>/<arg>",
-                     [this](QString message, int times, QHttpServerResponder &responder) {
-                         ++callCounter;
-                         auto device = new SequentialIODevice(message.toUtf8(), times, 50ms);
-                         responder.write(device, QHttpHeaders());
-                     });
+    httpserver.route(
+            "/sequential/<arg>/<arg>",
+            [this](QString message, int times, QHttpServerResponder &&responder) {
+                return QtConcurrent::run(
+                        &threadPool,
+                        [=, r = std::make_shared<QHttpServerResponder>(std::move(responder))]() {
+                            ++callCounter;
+                            auto device = new SequentialIODevice(message.toUtf8(), times, 50ms);
+                            r->write(device, QHttpHeaders());
+                        });
+            });
 
     auto tcpserver = std::make_unique<QTcpServer>();
     QVERIFY2(tcpserver->listen(), "HTTP server listen failed");
@@ -658,6 +664,9 @@ void tst_QHttpServerMultithreaded::initTestCase()
 
 #if QT_CONFIG(localserver)
     auto localserver = std::make_unique<QLocalServer>();
+#ifdef Q_OS_LINUX
+    localserver->setSocketOptions(QLocalServer::AbstractNamespaceOption);
+#endif
     localserver->removeServer(local);
     QVERIFY2(localserver->listen(local), "Local server listen failed");
     QVERIFY2(httpserver.bind(localserver.get()), "Local server bind failed");
@@ -779,7 +788,7 @@ void tst_QHttpServerMultithreaded::multipleCallsOnEachConnection()
 void tst_QHttpServerMultithreaded::moreConnectionsThanServerThreads()
 {
     QFETCH_GLOBAL(ServerType, serverType);
-    QList<QString> inputs(100);
+    QList<QString> inputs(25);
     for (qsizetype i = 0; i < inputs.size(); ++i)
         inputs[i] = u"Hey%1"_s.arg(i);
 
@@ -1057,14 +1066,17 @@ void tst_QHttpServerMultithreaded::oneSlowManyFast()
 
     QFETCH_GLOBAL(ServerType, serverType);
 
-    QFuture<QString> slowFuture = QtConcurrent::run([&]() {
+    QThreadPool clientThreadPool;
+    clientThreadPool.setMaxThreadCount(NumberOfFastTasks + 1);
+
+    QFuture<QString> slowFuture = QtConcurrent::run(&clientThreadPool, [&]() {
         LocalHttpClient client(serverType);
         return client.get(u"/wait/2000"_s);
     });
 
     QList<QFuture<QString>> fastFutures(NumberOfFastTasks);
     for (qsizetype i = 0; i < NumberOfFastTasks; ++i) {
-        fastFutures[i] = QtConcurrent::run([&]() {
+        fastFutures[i] = QtConcurrent::run(&clientThreadPool, [&]() {
             LocalHttpClient client(serverType);
             return client.get(u"/wait/200"_s);
         });
@@ -1104,8 +1116,6 @@ void tst_QHttpServerMultithreaded::sequentialDevice()
     QTRY_VERIFY(future.isFinished());
 
     QString returned = future.result();
-    if (serverType == HTTP1_0)
-        QSKIP("QTBUG-138410: The HTTP/1.0 support is incomplete: Flaky, mostly fails on HTTP/1.0");
     QCOMPARE(returned, u"HeyHeyHey"_s);
     QCOMPARE(getCallCount(), 1);
 }
